@@ -10,23 +10,24 @@ extern P_fun *P;
 extern G_fun *G;
 extern H_fun *H;
 
+/* Not used!?
 static void permute(int n, int *y, int *x)
 {
-/* Result in y; x is just a "work area" */
 
     int i, j, k;
 
-    k = n; /* Eg, "wt sampling k-of-n" */
+    k = n;
 
     for (i = 0; i < n; i++)
 	x[i] = i;
     for (i = 0; i < k; i++) {
 	j = n * unif_rand();
-/*	y[i] = x[j] + 1; */
+
 	y[i] = x[j];
 	x[j] = x[--n];
     }
 }
+*/
 
 void glmm_boot(int *family,
 	       int *p, 
